@@ -11,7 +11,9 @@ from __future__ import annotations
 import json
 import pathlib
 import warnings
+from copy import copy
 from os import PathLike
+from time import time
 
 from typing import Any, Callable, Dict, List, Optional, TypeVar, Union, cast
 
@@ -83,6 +85,7 @@ class Property(CallbackMixIn):
 
         self.name = name
         self._value = value
+        self.last_seen = None
 
         self.model = model
 
@@ -105,8 +108,14 @@ class Property(CallbackMixIn):
         """Sets the value of the key and schedules the callback."""
 
         self._value = new_value
+        self.last_seen = time()
         self.notify(self)
 
+    def copy(self):
+        """Returns a copy of self."""
+
+        return copy(self)
+
     def flatten(self) -> Dict[str, Any]:
         """Returns a dictionary with the name and value of the property."""
 
@@ -137,6 +146,7 @@ class BaseModel(CaseInsensitiveDict[T], CallbackMixIn):
     ):
 
         self.name = name
+        self.last_seen = None
 
         CaseInsensitiveDict.__init__(self, {})
         CallbackMixIn.__init__(self, [callback] if callback else [])
@@ -251,6 +261,8 @@ class Model(BaseModel[Property]):
         except jsonschema.exceptions.ValidationError as err:
             return False, err
 
+        self.last_seen = time()
+
         for key, value in instance.items():
             if key in self:
                 if isinstance(self[key].value, dict) and isinstance(value, dict):
@@ -261,7 +273,7 @@ class Model(BaseModel[Property]):
                     self[key].value = new_value
                 else:
                     self[key].value = value
-                self.notify(self, self[key])
+                self.notify(self, self[key].copy())
 
         return True, None
 
